@@ -1,5 +1,5 @@
 /* tables.h - IDNA tables
-   Copyright (C) 2011-2014 Simon Josefsson
+   Copyright (C) 2011-2016 Simon Josefsson
 
    Libidn2 is free software: you can redistribute it and/or modify it
    under the terms of either:
@@ -27,6 +27,7 @@
 */
 
 #include <stdint.h>
+#include <sys/types.h>
 
 enum
 {
@@ -41,3 +42,4 @@ struct idna_table
 };
 
 extern const struct idna_table idna_table[];
+extern const size_t idna_table_size;
